unit SOAPIntf;

//This unit is used by both client and server where both are written in Delphi,
//since both sides will need to access the interface definitions

interface

type
  //This is an invokable interface (an interface with RTTI generated for it)
  //The ancestor, IInvokable, is compiled with the $M+ directive and
  //is based on IInterface (same as IUnknown)
  IGeometry = interface(IInvokable)
  ['{C0FCD1F8-DFD8-4AB7-8E80-C3B1C17BE7C1}']
    function SphereVolume(Radius: Double): Double; stdcall;
    function CircleArea(Radius: Double): Double; stdcall;
  end;

implementation

uses
  InvokeRegistry;

initialization
  //Register interface with invocation registry

  //On the server, the invocation registry entry allows the invoker
  //component (THTTPSOAPPascalInvoker) to identify an implementation
  //class to use for executing interface calls.

  //On client applications, an invocation registry entry allows components
  //to look up information that identifies the invokable interface and
  //supplies information on how to call it.

  //InvokeRegistry.InvRegistry maintains in memory a catalog of all
  //registered invokable interfaces, their implementation classes, and
  //the factories that create instances of the implementation classes.

  //When you register an interface the invocation registry automatically
  //generates a namespace for the interface (the interfaces of Web Services
  //must have a namespace to identify them among all the interfaces in all
  //possible Web Services).
  //The default namespace is built from a string that uniquely identifies
  //the application (the AppNamespacePrefix variable), the interface name,
  //and the name of the unit in which it is defined.
  InvRegistry.RegisterInterface(TypeInfo(IGeometry), '', '', 'Provides various geometry routines')
end.
